@@ -1,5 +1,4 @@
 import { css, cx } from '@emotion/css';
-import { useState } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { CollapsableSection, useStyles2 } from '@grafana/ui';
@@ -9,20 +8,19 @@ export default function ReportSection({
   children,
   contentClassName,
   dataTestId,
-  defaultOpen = false,
+  isOpen,
+  onToggle,
+  contentDataTestId,
 }: {
   label: string;
   children: React.ReactNode;
-  defaultOpen?: boolean;
+  isOpen: boolean;
+  onToggle: (isOpen: boolean) => void;
   contentClassName?: string;
   dataTestId?: string;
+  contentDataTestId?: string;
 }) {
   const styles = useStyles2(getStyles);
-  const [isOpen, setIsOpen] = useState(defaultOpen);
-
-  const onToggle = () => {
-    setIsOpen((prevState) => !prevState);
-  };
 
   return (
     <CollapsableSection
@@ -31,7 +29,9 @@ export default function ReportSection({
       label={label}
       className={styles.sectionTitle}
       contentClassName={cx(styles.content, contentClassName)}
+      unmountContentWhenClosed={false}
       headerDataTestId={dataTestId}
+      contentDataTestId={contentDataTestId}
     >
       {children}
     </CollapsableSection>
