@@ -1,5 +1,5 @@
+import { t } from '@grafana/i18n';
 import { Alert } from '@grafana/ui';
-import { t } from 'app/core/internationalization';
 
 export const missingRightsMessage =
   'You are not allowed to modify this data source. Please contact your server admin to update this data source.';
